/*
 * SoundSynthesizer_Defs.h
 *
 *  Created on: Aug 25, 2015
 *      Author: RK
 */

#ifndef SOUNDSYNTHESIZER_DEFS_H_
#define SOUNDSYNTHESIZER_DEFS_H_

#define BIT7 0x80
#define BIT6 0x40
#define BIT5 0x20
#define BIT4 0x10
#define BIT3 0x08
#define BIT2 0x04
#define BIT1 0x02
#define BIT0 0x01

#define HIGH 1
#define LOW 0

#define TRUE 1
#define FALSE 0

/**************************************
output frequency timing
**************************************/
/*PCA clock period was measured at 488 ns.
For note C5 (523.25 Hz) output, the period is 1.9 ms.
1.9 ms divided by 488 ns = 3916.
So, 3916 PCA clocks gives the proper period for a C5 output.
However, we need to add only half of this value to the capture/compare
register because a match between the capture/compare
register and the PCA counter causes the output pin to toggle,
and one clock period requires two toggles.
The frequency of the clock that drives the lowpass filter is 125 times
higher than the frequency of the sound signal, which means that the
period is 125 times shorter. Thus, we divide the sound-signal increment
by 125 to obtain the filter-clock increment.
This same procedure is used to calculate the sound-signal and clock-signal
increments for all the notes.*/
#define SOUND_C5_INCREMENT 1958
#define FILTCLK_C5_INCREMENT 16
#define SOUND_D5_INCREMENT 1744
#define FILTCLK_D5_INCREMENT 14
#define SOUND_E5_INCREMENT 1554
#define FILTCLK_E5_INCREMENT 12
#define SOUND_F5_INCREMENT 1467
#define FILTCLK_F5_INCREMENT 12
#define SOUND_G5_INCREMENT 1307
#define FILTCLK_G5_INCREMENT 10
#define SOUND_A5_INCREMENT 1164
#define FILTCLK_A5_INCREMENT 9
#define SOUND_B5_INCREMENT 1037
#define FILTCLK_B5_INCREMENT 8
#define SOUND_C6_INCREMENT 979
#define FILTCLK_C6_INCREMENT 8



#define LOWBYTE(v)   ((unsigned char) (v))
#define HIGHBYTE(v)  ((unsigned char) (((unsigned int) (v)) >> 8))



//global variables shared across files
extern unsigned int Current_SoundSignal_Increment;
extern unsigned int Current_FilterClock_Increment;

//function prototypes


//port pins
sbit RGBLED_G = P1^4;
sbit RGBLED_B = P1^5;
sbit RGBLED_R = P1^6;

#endif /*SOUNDSYNTHESIZER_DEFS_H_ */
